OMConfig class

Constructors

OMConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

callbackUrl String
getter/setter pair
clientId String
getter/setter pair
clientSecret String
getter/setter pair
isSandbox bool
getter/setter pair
merchantKey String
getter/setter pair

Static Methods

init({required String clientIdParam, required String clientSecretParam, required String merchantKeyParam, required String callbackUrlParam, bool sandbox = true}) → void